@@ -46,3 +46,7 @@ class Input:
         proxy_list = self.get_proxies()
         if proxy_list:
             return random.choice(proxy_list)
+
+    @staticmethod
+    def is_free_user():
+        return os.getenv('user_plan'.upper()) == 'FREE'
